"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isAuthValid = void 0;
const quidproquo_core_1 = require("quidproquo-core");
const verifyJwt_1 = require("../../../../logic/cognito/verifyJwt");
const getExportedValue_1 = require("../../../../logic/cloudformation/getExportedValue");
const awsNamingUtils_1 = require("../../../../awsNamingUtils");
const isAuthValid = (qpqConfig, authHeader, authSettings) => __awaiter(void 0, void 0, void 0, function* () {
    // If there are no auth settings ~ Its valid.
    if (!authSettings || !authSettings.userDirectoryName) {
        return true;
    }
    // We need a header to be able to auth
    if (!authHeader) {
        return false;
    }
    // Make sure we have a Bearer token
    const [authType, accessToken] = authHeader.split(' ');
    if (authType !== 'Bearer' || !accessToken) {
        return false;
    }
    // Grab the user directory to auth against
    const userDirectoryName = authSettings.userDirectoryName;
    const region = quidproquo_core_1.qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
    // Resolve the user pool id
    const userPoolId = yield (0, getExportedValue_1.getExportedValue)((0, awsNamingUtils_1.getCFExportNameUserPoolIdFromConfig)(userDirectoryName, qpqConfig, authSettings.serviceName, authSettings.applicationName), region);
    // Resolve the user pool client id
    const userPoolClientId = yield (0, getExportedValue_1.getExportedValue)((0, awsNamingUtils_1.getCFExportNameUserPoolClientIdFromConfig)(userDirectoryName, qpqConfig, authSettings.serviceName, authSettings.applicationName), region);
    // Verify the token
    return yield (0, verifyJwt_1.verifyJwt)(accessToken, userPoolId, userPoolClientId, 'access');
});
exports.isAuthValid = isAuthValid;
